@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.3.0", __name__, "aws-kms@1.3.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.4.0", __name__, "aws-kms@1.4.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'alias_target_key': 'aliasTargetKey'})
 class AliasAttributes():
     def __init__(self, *, alias_name: str, alias_target_key: "IKey"):
@@ -688,18 +688,19 @@ class Key(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
     resource:
     :resource:: AWS::KMS::Key
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, alias: typing.Optional[str]=None, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None) -> None:
         """
         :param scope: -
         :param id: -
         :param props: -
+        :param alias: Initial alias to add to the key. More aliases can be added later by calling ``addAlias``. Default: - No alias is added for the key.
         :param description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task. Default: - No description.
         :param enabled: Indicates whether the key is available for use. Default: - Key is enabled.
         :param enable_key_rotation: Indicates whether AWS KMS rotates the key. Default: false
         :param policy: Custom policy document to attach to the KMS key. Default: - A policy document with permissions for the account root to administer the key will be created.
         :param removal_policy: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: RemovalPolicy.Retain
         """
-        props = KeyProps(description=description, enabled=enabled, enable_key_rotation=enable_key_rotation, policy=policy, removal_policy=removal_policy)
+        props = KeyProps(alias=alias, description=description, enabled=enabled, enable_key_rotation=enable_key_rotation, policy=policy, removal_policy=removal_policy)
 
         jsii.create(Key, self, [scope, id, props])
 
@@ -785,11 +786,12 @@ class Key(aws_cdk.core.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
         return jsii.get(self, "policy")
 
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-kms.KeyProps", jsii_struct_bases=[], name_mapping={'description': 'description', 'enabled': 'enabled', 'enable_key_rotation': 'enableKeyRotation', 'policy': 'policy', 'removal_policy': 'removalPolicy'})
+@jsii.data_type(jsii_type="@aws-cdk/aws-kms.KeyProps", jsii_struct_bases=[], name_mapping={'alias': 'alias', 'description': 'description', 'enabled': 'enabled', 'enable_key_rotation': 'enableKeyRotation', 'policy': 'policy', 'removal_policy': 'removalPolicy'})
 class KeyProps():
-    def __init__(self, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None):
+    def __init__(self, *, alias: typing.Optional[str]=None, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy]=None):
         """Construction properties for a KMS Key object.
 
+        :param alias: Initial alias to add to the key. More aliases can be added later by calling ``addAlias``. Default: - No alias is added for the key.
         :param description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task. Default: - No description.
         :param enabled: Indicates whether the key is available for use. Default: - Key is enabled.
         :param enable_key_rotation: Indicates whether AWS KMS rotates the key. Default: false
@@ -798,12 +800,24 @@ class KeyProps():
         """
         self._values = {
         }
+        if alias is not None: self._values["alias"] = alias
         if description is not None: self._values["description"] = description
         if enabled is not None: self._values["enabled"] = enabled
         if enable_key_rotation is not None: self._values["enable_key_rotation"] = enable_key_rotation
         if policy is not None: self._values["policy"] = policy
         if removal_policy is not None: self._values["removal_policy"] = removal_policy
 
+    @property
+    def alias(self) -> typing.Optional[str]:
+        """Initial alias to add to the key.
+
+        More aliases can be added later by calling ``addAlias``.
+
+        default
+        :default: - No alias is added for the key.
+        """
+        return self._values.get('alias')
+
     @property
     def description(self) -> typing.Optional[str]:
         """A description of the key.
